<?php

namespace app\admin\controller\News;

use app\BaseController;
use app\common\model\News\News as ModelNews;
use app\Request;
use think\Validate;
use think\exception\ValidateException;
use think\facade\Filesystem;
use app\common\arw\adjfut\src\Excel;
use app\common\arw\adjfut\src\UploadFile;
use app\common\exception\Tool;
use think\facade\Db;
use think\facade\Env;


class News extends BaseController
{
    /**
     * 获取新闻列表
     */
    public function getNewsList(Request $request, $isExport = false): array
    {
        $params = $request->param();
        $con = [];

        $con = Tool::getOptionalQuery(['news_type','='],['news_title','LIKE'],);

        $query = ModelNews::where($con)
            ->field([
'news_id',
'news_guid',
'news_type',
'news_title',
'news_intro',
'news_source',
'news_link',
'news_issue_date',
'news_views_num',
'news_sort',
'news_content'
])
            ->order('news_sort', 'asc');

        return $isExport ?  $query->select()->toArray() : msg("获取新闻列表成功!",$query);
    }

    /**
     * 添加新闻
     */
    public function addNews(Request $request): array
    {
        Db::startTrans();
        Tool::adminLockTableWrite('news');
        try {
        $params = $request->param();
        $this->validate($params, [
'news_type|新闻类型'=>'require',
'news_title|新闻标题'=>'require',
'news_sort|新闻排序'=>'require'
]);
        $model = ModelNews::create($params,[
'news_type',
'news_title',
'news_intro',
'news_source',
'news_link',
'news_issue_date',
'news_views_num',
'news_sort',
'news_content',
'news_guid',
'news_create_user_guid',
'news_update_user_guid'
]);
        Db::commit();
        Tool::unlockTable();
        return msg('添加成功!');
        } catch (\Throwable $th) {
            Db::rollback();
            Tool::unlockTable();
            throw  $th;
        }
    }

    /**
     * 编辑新闻
     */
    public function editNews(Request $request): array
    {
        Db::startTrans();
        Tool::adminLockTableWrite('news');
        try {
        $params = $request->param();
        $this->validate($params, [
'news_type|新闻类型'=>'require',
'news_title|新闻标题'=>'require',
'news_sort|新闻排序'=>'require'
]);
        $model = ModelNews::where('news_guid',$params['news_guid'])->find();
        if (!$model) throwErrorMsg("该新闻不存在", 1);
        $model->allowField([
'news_type',
'news_title',
'news_intro',
'news_source',
'news_link',
'news_issue_date',
'news_views_num',
'news_sort',
'news_content',
'news_update_user_guid'
])->save($params);
        Db::commit();
        Tool::unlockTable();
        return msg('编辑成功!');
        } catch (\Throwable $th) {
            Db::rollback();
            Tool::unlockTable();
            throw  $th;
        }
    }

    /**
     * 删除新闻
     */
    public function deleteNews(Request $request): array
    {
        Db::startTrans();
        Tool::adminLockTableWrite('news');
        try {
        $params = $request->param();
        $this->validate($params, [
            'news_guid' => 'require',
        ]);
        $news = ModelNews::where([
            'news_guid' => explode(',', $params['news_guid'])
        ])->select();
        $news->delete();
        Db::commit();
        Tool::unlockTable();
        return msg('删除成功!');
        } catch (\Throwable $th) {
            Db::rollback();
            Tool::unlockTable();
            throw  $th;
        }
    }

    /**
* 导出Excel
*/
        public function exportExcel(Request $request):void
        {
             ModelNews::exportExcel(self::getNewsList($request, true));
        }

    /**
* 下载导入模板
*/
        public function downloadTemplate(Request $request):void
        {
            $params = $request->param();
            $data = [
                array_values(ModelNews::EXCELFIELD),
                ['默认值1','默认值2','默认值3','默认值4','默认值5','默认值6','默认值7','默认值8','默认值9',]
            ];
            $excel = (new Excel())->exporTsheet($data);
            $excel->save('新闻导入模板.xlsx');
        }

    /**
* 导入excel
*/
        public function importExcel(Request $request):array
        {
            $file = new UploadFile('uploads', 'fileExt:xlsx');
            $file->putFile('news');
            $msg = ModelNews::importExcel($file);
            return [
                'code' => 0,
                'msg' => $msg
            ];
        }

}
